.. :changelog:

History
-------

1.0.4 (2018-12-17)
++++++++++++++++++

- Drop support of Python 3.4
- Confirm support of Python 3.7
- Drop support of Django 1.8
- Drop support of Django 1.9
- Drop support of Django 1.10
- Confirm support of Django 2.0
- Confirm support of Django 2.1


1.0.3 (2018-04-26)
++++++++++++++++++

- Python 3.6 support
- Multiple databases support
- Github organization changed to "peopledoc"


1.0.2 (2017-09-22)
++++++++++++++++++

* Added tests for Django 1.11

1.0.1 (2016-10-19)
++++++++++++++++++

* Added support for Python 3.4 and current Django stable
* Fix a thread bug that would make the package usable only for test and not for real :/

1.0.0 (2016-09-15)
++++++++++++++++++

* First stable version

0.2.0 (2016-09-14)
++++++++++++++++++

* Rationalized the writing of readonly (vs read-only)
* Defined default app config

0.1.1 (2016-09-13)
++++++++++++++++++

* CI improvements
* Code linting


0.1.0 (2016-09-02)
++++++++++++++++++

* First release on PyPI.
